cmd

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 16, 2025 License: MIT Imports: 19 Imported by: 0

Documentation

Overview

Copyright © 2025 NAME HERE <EMAIL ADDRESS>

Copyright © 2025 NAME HERE <EMAIL ADDRESS>

Index

Constants

const (
	LookupFile = "registry.gob"
)

Variables

var ErrInvalidEUIFormat = fmt.Errorf("not a valid EUIFormat, try [%s]", strings.Join(_EUIFormatNames, ", "))

Functions

func EUIFormatNames

func EUIFormatNames() []string

EUIFormatNames returns a list of possible string values of EUIFormat.

func Execute

func Execute()

func SetVersion

func SetVersion(version string)

Types

type AtInputPositionError

type AtInputPositionError struct {
	Position int
	Err      error
}

func (AtInputPositionError) Error

func (e AtInputPositionError) Error() string

func (AtInputPositionError) Unwrap

func (e AtInputPositionError) Unwrap() error

type EUIFormat

type EUIFormat string //nolint: recvcheck // generated by a third-party

ENUM(COLON, DASH, DOT, PLAIN).

const (
	// EUIFormatCOLON is a EUIFormat of type COLON.
	EUIFormatCOLON EUIFormat = "COLON"
	// EUIFormatDASH is a EUIFormat of type DASH.
	EUIFormatDASH EUIFormat = "DASH"
	// EUIFormatDOT is a EUIFormat of type DOT.
	EUIFormatDOT EUIFormat = "DOT"
	// EUIFormatPLAIN is a EUIFormat of type PLAIN.
	EUIFormatPLAIN EUIFormat = "PLAIN"
)

func EUIFormatValues

func EUIFormatValues() []EUIFormat

EUIFormatValues returns a list of the values for EUIFormat

func ParseEUIFormat

func ParseEUIFormat(name string) (EUIFormat, error)

ParseEUIFormat attempts to convert a string to a EUIFormat.

func (*EUIFormat) Get

func (x *EUIFormat) Get() interface{}

Get implements the Golang flag.Getter interface func.

func (EUIFormat) IsValid

func (x EUIFormat) IsValid() bool

IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values

func (*EUIFormat) Set

func (x *EUIFormat) Set(val string) error

Set implements the Golang flag.Value interface func.

func (EUIFormat) String

func (x EUIFormat) String() string

String implements the Stringer interface.

func (*EUIFormat) Type

func (x *EUIFormat) Type() string

Type implements the github.com/spf13/pFlag Value interface.

type RecordResponse

type RecordResponse struct {
	Input    string            `json:"input"`
	InputRaw string            `json:"input_raw"`
	Records  []registry.Record `json:"records"`
}

Jump to