Documentation
¶
Overview ¶
Copyright © 2025 NAME HERE <EMAIL ADDRESS>
Copyright © 2025 NAME HERE <EMAIL ADDRESS>
Index ¶
Constants ¶
const (
LookupFile = "registry.gob"
)
Variables ¶
var ErrInvalidEUIFormat = fmt.Errorf("not a valid EUIFormat, try [%s]", strings.Join(_EUIFormatNames, ", "))
Functions ¶
func EUIFormatNames ¶
func EUIFormatNames() []string
EUIFormatNames returns a list of possible string values of EUIFormat.
func SetVersion ¶
func SetVersion(version string)
Types ¶
type AtInputPositionError ¶
func (AtInputPositionError) Error ¶
func (e AtInputPositionError) Error() string
func (AtInputPositionError) Unwrap ¶
func (e AtInputPositionError) Unwrap() error
type EUIFormat ¶
type EUIFormat string //nolint: recvcheck // generated by a third-party
ENUM(COLON, DASH, DOT, PLAIN).
const ( // EUIFormatCOLON is a EUIFormat of type COLON. EUIFormatCOLON EUIFormat = "COLON" // EUIFormatDASH is a EUIFormat of type DASH. EUIFormatDASH EUIFormat = "DASH" // EUIFormatDOT is a EUIFormat of type DOT. EUIFormatDOT EUIFormat = "DOT" // EUIFormatPLAIN is a EUIFormat of type PLAIN. EUIFormatPLAIN EUIFormat = "PLAIN" )
func EUIFormatValues ¶
func EUIFormatValues() []EUIFormat
EUIFormatValues returns a list of the values for EUIFormat
func ParseEUIFormat ¶
ParseEUIFormat attempts to convert a string to a EUIFormat.
func (*EUIFormat) Get ¶
func (x *EUIFormat) Get() interface{}
Get implements the Golang flag.Getter interface func.
func (EUIFormat) IsValid ¶
IsValid provides a quick way to determine if the typed value is part of the allowed enumerated values
Click to show internal directories.
Click to hide internal directories.